# 乇乂丅尺卂 丅卄工匚匚

A Python module for generating an EXTRA THICC text.

# How to use

Import an `extra_thicc` module and use a `make_extra_thicc` function:

```python
from extra_thicc import make_extra_thicc

make_extra_thicc("extra thicc")
# >>> '乇乂丅尺卂 丅卄工匚匚'
```

run using poetry:
```
poetry run python src/extra_thicc.py <INPUT>
```

or install and use a console script `make-extra-thicc`:

```bash
$ make-extra-thicc 'extra thicc'
乇乂丅尺卂 丅卄工匚匚
```

### Run tests
```
poetry run pytest
```
